@@ -1,5 +1,5 @@
 # typedload
-# Copyright (C) 2018-2021 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2024 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@ from dataclasses import dataclass, field
 from enum import Enum
 from typing import Dict, List, NamedTuple, Optional, Set, Tuple, Union
 import unittest
+import sys
 
 from typedload import dataloader, load, dump, typechecks, exceptions
 
@@ -79,6 +80,14 @@ class TestDataclassLoad(unittest.TestCase):
             b: str
         assert load({'a': 101, 'b': 'ciao'}, A) == A(101, 'ciao')
 
+    if sys.version_info.minor >= 10:
+        def test_loadslotted(self):
+            @dataclass(slots=True)
+            class A:
+                a: int
+
+            assert load({'a': 1}, A) == A(1)
+
     def test_nestedload(self):
         @dataclass
         class A:
@@ -141,6 +150,14 @@ class TestDataclassDump(unittest.TestCase):
         assert dump(A(12)) == {'a': 12}
         assert dump(A(12), hidedefault=False) == {'a': 12, 'b': 0}
 
+    if sys.version_info.minor >= 10:
+        def test_dump_slots(self):
+            @dataclass(slots=True)
+            class A:
+                a: int
+
+            assert dump(A(1)) == {'a': 1}
+
     def test_factory_dump(self):
         @dataclass
         class A:
