@@ -16,18 +16,36 @@
 #
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 from enum import Enum
-from typing import Dict, FrozenSet, List, NamedTuple, Optional, Set, Tuple, Union, Any, NewType
+from typing import Dict, FrozenSet, List, NamedTuple, Optional, Set, Tuple, Union, Any, NewType, Literal
 import unittest
 import sys
 
-if sys.version_info.minor >= 8:
-    from typing import Literal
-
 from typedload import typechecks
 
 
 class TestChecks(unittest.TestCase):
 
+
+    def test_is_readonly(self):
+        assert (not typechecks.is_readonly(None))
+        # Only from 3.13
+        if sys.version_info.minor < 13:
+            return
+        from typing import ReadOnly
+        assert typechecks.is_readonly(ReadOnly[int])
+        assert typechecks.is_readonly(ReadOnly[str])
+        assert typechecks.is_readonly(ReadOnly[Union[int, str]])
+        assert not typechecks.is_readonly(list[int])
+        assert not typechecks.is_readonly(list[str])
+        assert not typechecks.is_readonly(list[Union[int, str]])
+
+    def test_readonly(self):
+        # Only from 3.13
+        if sys.version_info.minor < 13:
+            return
+        from typing import ReadOnly
+        assert int == typechecks.readonlytype(ReadOnly[int])
+
     def test_is_not_required(self):
         if sys.version_info.minor >= 11:
             from typing import NotRequired, Required
@@ -64,11 +82,16 @@ class TestChecks(unittest.TestCase):
         from typing import Required
         assert int == typechecks.requiredtype(Required[int])
 
-    def test_is_literal(self):
-        if sys.version_info.minor >= 8:
-            l = Literal[1, 2, 3]
-            assert typechecks.is_literal(l)
+    def test_literalvalues(self):
+        l = Literal[1, 2, 3]
+        assert 1 in typechecks.literalvalues(l)
+        assert 2 in typechecks.literalvalues(l)
+        assert 3 in typechecks.literalvalues(l)
+        assert 4 not in typechecks.literalvalues(l)
 
+    def test_is_literal(self):
+        l = Literal[1, 2, 3]
+        assert typechecks.is_literal(l)
         assert not typechecks.is_literal(3)
         assert not typechecks.is_literal(int)
         assert not typechecks.is_literal(str)
@@ -93,9 +116,8 @@ class TestChecks(unittest.TestCase):
         assert not typechecks.is_list(Tuple[int, str])
         assert not typechecks.is_list(Dict[int, str])
         assert not typechecks.is_list([])
-        if sys.version_info.minor >= 9:
-            assert typechecks.is_list(list[str])
-            assert not typechecks.is_list(tuple[str])
+        assert typechecks.is_list(list[str])
+        assert not typechecks.is_list(tuple[str])
 
     def test_is_dict(self):
         assert typechecks.is_dict(Dict[int, int])
@@ -103,33 +125,29 @@ class TestChecks(unittest.TestCase):
         assert typechecks.is_dict(Dict[str, str])
         assert not typechecks.is_dict(Tuple[str, str])
         assert not typechecks.is_dict(Set[str])
-        if sys.version_info.minor >= 9:
-            assert typechecks.is_dict(dict[str, str])
-            assert not typechecks.is_dict(tuple[str])
+        assert typechecks.is_dict(dict[str, str])
+        assert not typechecks.is_dict(tuple[str])
 
     def test_is_set(self):
         assert typechecks.is_set(Set[int])
         assert typechecks.is_set(Set)
-        if sys.version_info.minor >= 9:
-            assert typechecks.is_set(set[str])
-            assert not typechecks.is_set(tuple[str])
+        assert typechecks.is_set(set[str])
+        assert not typechecks.is_set(tuple[str])
 
     def test_is_frozenset_(self):
         assert not typechecks.is_frozenset(Set[int])
         assert typechecks.is_frozenset(FrozenSet[int])
         assert typechecks.is_frozenset(FrozenSet)
-        if sys.version_info.minor >= 9:
-            assert typechecks.is_frozenset(frozenset[str])
-            assert not typechecks.is_frozenset(tuple[str])
+        assert typechecks.is_frozenset(frozenset[str])
+        assert not typechecks.is_frozenset(tuple[str])
 
     def test_is_tuple(self):
         assert typechecks.is_tuple(Tuple[str, int, int])
         assert typechecks.is_tuple(Tuple)
         assert not typechecks.is_tuple(tuple)
         assert not typechecks.is_tuple((1,2))
-        if sys.version_info.minor >= 9:
-            assert typechecks.is_tuple(tuple[str])
-            assert not typechecks.is_tuple(list[str])
+        assert typechecks.is_tuple(tuple[str])
+        assert not typechecks.is_tuple(list[str])
 
     def test_is_union(self):
         assert typechecks.is_union(Optional[int])
