@@ -4,7 +4,7 @@ typedload
 Internal helper functions
 """
 
-# Copyright (C) 2021 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2021-2024 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,10 +21,6 @@ Internal helper functions
 #
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 
-from enum import Enum
-from typing import Any, Tuple, Union, Set, List, Dict, Type, FrozenSet
-
-
 __all__ = [
     'tname',
 ]
